@@ -1,10 +1,9 @@
 # $File: //member/autrijus/HTML-FromANSI/FromANSI.pm $ $Author: autrijus $
-# $Revision: #3 $ $Change: 2452 $ $DateTime: 2001/11/28 04:02:46 $
+# $Revision: #4 $ $Change: 2623 $ $DateTime: 2001/12/16 00:05:58 $
 
 package HTML::FromANSI;
-$HTML::FromANSI::VERSION = '0.01';
+$HTML::FromANSI::VERSION = '0.02';
 
-use bytes;
 use strict;
 use vars qw/@EXPORT/;
 use base qw/Exporter/;
@@ -20,19 +19,20 @@ HTML::FromANSI - Mark up ANSI sequences as HTML
     use HTML::FromANSI;
     use Term::ANSIColor;
 
-    print ansi2html(color('bold blue')."This text is bold blue.");
+    print ansi2html(color('bold blue'), "This text is bold blue.");
 
 =head1 DESCRIPTION
 
-This little module converts ANSI text sequences to corresponding HTML
+This small module converts ANSI text sequences to corresponding HTML
 codes, using stylesheets to control color and blinking properties.
 
-It exports C<ansi2html> by default.
+It exports C<ansi2html> by default, which takes an array, joins it
+it into a single scalar, and returns its HTML rendering.
 
-=head1 BUGS
+=head1 CAVEATS
 
-The implementation is exceptionally ugly. I plan on fixing it in an
-indeterminable future.
+The implementation is exceptionally kludgey. I plan on fixing it in an
+indeterminable future. It's nowhere need a top priority, though.
 
 =cut
 
@@ -74,11 +74,13 @@ sub init {
 sub ansi2html {
     init();
 
-    return '<pre><font face="fixedsys, lucida console, terminal, vga, monospace">'.
-	   '<font color="#aaaaaa"><span style="{letter-spacing: 0; font-size: 12pt;}">'.
-	   parseansi("@_").
-	   '</span></font>'.
-	   '</pre>';
+    return (
+	'<pre><font face="fixedsys, lucida console, terminal, vga, monospace">'.
+	'<font color="#aaaaaa"><span style="{letter-spacing: 0; font-size: 12pt;}">'.
+	parseansi(join('', @_)).
+	'</span></font>'.
+	'</pre>' # The missing </font> supplied by parseansi
+    );
 }
 
 sub parseansi {
@@ -98,14 +100,18 @@ sub parseansi {
 
     while ( $strpos < length($text) ) {
         $char = substr( $text, $strpos, 1 );
+
         if ( $char =~ /\x1b/ ) {
             $ansi_code = '';
+
             until ( $char =~ /[a-zA-Z]/ or $strpos > length($text) ) {
                 $ansi_code .= $char;
                 $strpos += 1;
                 $char = substr( $text, $strpos, 1 );
             }
+
             $ansi_code .= $char;
+
             if ( $ansi_code =~ /\x1b\[([0-9]*)C/ ) {
                 $line_pos += $1;
                 $this_line .= substr( $nbspaces, 1, $1 );
@@ -121,20 +127,25 @@ sub parseansi {
         }
         elsif ( $char =~ /\x0d/ ) {
             $strpos += 1;
+
             if ( $strpos < length($text) ) {
                 $ansi_code = '';
                 $char = substr( $text, $strpos, 1 );
+
                 if ( $char =~ /\x1b/ ) {
                     until ( $char =~ /[a-zA-Z]/ or $strpos > length($text) ) {
                         $ansi_code .= $char;
                         $strpos += 1;
                         $char = substr( $text, $strpos, 1 );
                     }
+
                     $ansi_code .= $char;
+
                     if ( $ansi_code eq "\x1b[A" ) {
                         $ansi_code = '';
                         $strpos += 1;
                         $char = substr( $text, $strpos, 1 );
+
                         if ( $char eq "\x1b" ) {
                             until ( $char =~ /[a-zA-Z]/
                                 or $strpos > length($text) )
@@ -143,7 +154,9 @@ sub parseansi {
                                 $strpos += 1;
                                 $char = substr( $text, $strpos, 1 );
                             }
+
                             $ansi_code .= $char;
+
                             if ( $ansi_code =~ /\x1b\[([0-9]+)C/ ) {
                                 $new_text .=
                                   substr( $nbspaces, 0, $1 - $line_pos );
@@ -229,6 +242,7 @@ sub parseansi {
 
     while ( $strpos < length($text) ) {
         $char = substr( $text, $strpos, 1 );
+
         if ( $char ne "\x1b" ) {
             if ( $char eq '('
                 && substr( $text, $strpos + 1, 1 ) ne "'"
@@ -239,13 +253,16 @@ sub parseansi {
                 $html_color = $1;
                 $html_style = $styles{".a$blink-$attr-$foreground-$background"};
                 $html_style =~ s/(?<=[\s{])color: ([^;]*);//g;
+
                 $new_text .= "</font><FONT color=\"$html_color\">"
                   if ( $old_html_color ne $html_color );
                 $new_text .= "</SPAN><SPAN style=\"$html_style\">"
                   if ( $html_style ne $old_style );
+
                 $old_style      = $html_style;
                 $old_html_color = $html_color;
             }
+
             $new_text .= $char;
             $strpos += 1;
         }
@@ -256,10 +273,12 @@ sub parseansi {
             {
                 $code_length += 1;
             }
-            $ansi_code = substr( $text, $strpos, $code_length + 1 );
+
+            $ansi_code  = substr( $text, $strpos, $code_length + 1 );
             $attributes = $ansi_code;
             $attributes =~ s/[^0-9;]//g;
             @attributes = split ( /;/, $attributes );
+
             foreach $attribute (@attributes) {
                 if ( $attribute eq '0' ) {
                     $attr       = '0';
@@ -306,7 +325,7 @@ sub parseansi {
 
 =head1 SEE ALSO
 
-L<ansi2html>, L<Term::ANSIColor>.
+L<ansi2html>, L<Term::ANSIColor>, L<Term::ANSIScreen>.
 
 =head1 AUTHORS
 
@@ -317,8 +336,10 @@ Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 Copyright 2001 by Stephen Hurd E<lt>shurd@sk.sympatico.caE<gt>.
 
-Picked up, cleaned various bits, fixed bugs and turned into a module
-by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Picked up, cleaned up various bits, fixed bugs and turned into a
+CPAN module by Autrijus Tang.
+
+Copyright 2001 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
@@ -329,25 +350,26 @@ See L<http://www.perl.com/perl/misc/Artistic.html>
 
 __DATA__
 a              {text-decoration: none;}
+a:hover        {text-decoration: underline;}
 a:visited      {text-decoration: none;}
 a:link         {text-decoration: none;}
-.a-0-30-40     {color: black; background-color: black;}
-.a-0-31-40     {color: #aa0000; background-color: black;}
-.a-0-32-40     {color: #00aa00; background-color: black;}
-.a-0-33-40     {color: #aaaa00; background-color: black;}
-.a-0-34-40     {color: #0000aa; background-color: black;}
-.a-0-35-40     {color: #aa00aa; background-color: black;}
-.a-0-36-40     {color: #00aaaa; background-color: black;}
-.a-0-37-40     {color: #aaaaaa; background-color: black;}
-.a-1-30-40     {color: #444444; background-color: black;}
-.a-1-31-40     {color: #ff4444; background-color: black;}
-.a-1-32-40     {color: #44ff44; background-color: black;}
-.a-1-33-40     {color: #ffff44; background-color: black;}
-.a-1-34-40     {color: #4444ff; background-color: black;}
-.a-1-35-40     {color: #ff44ff; background-color: black;}
-.a-1-36-40     {color: #44ffff; background-color: black;}
-.a-1-37-40     {color: white; background-color: black;}
-.a-0-30-41     {color: black; background-color: #aa0000;}
+.a-0-30-40     {color: #000000; background-color: #000000;}
+.a-0-31-40     {color: #aa0000; background-color: #000000;}
+.a-0-32-40     {color: #00aa00; background-color: #000000;}
+.a-0-33-40     {color: #aaaa00; background-color: #000000;}
+.a-0-34-40     {color: #0000aa; background-color: #000000;}
+.a-0-35-40     {color: #aa00aa; background-color: #000000;}
+.a-0-36-40     {color: #00aaaa; background-color: #000000;}
+.a-0-37-40     {color: #aaaaaa; background-color: #000000;}
+.a-1-30-40     {color: #444444; background-color: #000000;}
+.a-1-31-40     {color: #ff4444; background-color: #000000;}
+.a-1-32-40     {color: #44ff44; background-color: #000000;}
+.a-1-33-40     {color: #ffff44; background-color: #000000;}
+.a-1-34-40     {color: #4444ff; background-color: #000000;}
+.a-1-35-40     {color: #ff44ff; background-color: #000000;}
+.a-1-36-40     {color: #44ffff; background-color: #000000;}
+.a-1-37-40     {color: #ffffff; background-color: #000000;}
+.a-0-30-41     {color: #000000; background-color: #aa0000;}
 .a-0-31-41     {color: #aa0000; background-color: #aa0000;}
 .a-0-32-41     {color: #00aa00; background-color: #aa0000;}
 .a-0-33-41     {color: #aaaa00; background-color: #aa0000;}
@@ -362,8 +384,8 @@ a:link         {text-decoration: none;}
 .a-1-34-41     {color: #4444ff; background-color: #aa0000;}
 .a-1-35-41     {color: #ff44ff; background-color: #aa0000;}
 .a-1-36-41     {color: #44ffff; background-color: #aa0000;}
-.a-1-37-41     {color: white; background-color: #aa0000;}
-.a-0-30-42     {color: black; background-color: #00aa00;}
+.a-1-37-41     {color: #ffffff; background-color: #aa0000;}
+.a-0-30-42     {color: #000000; background-color: #00aa00;}
 .a-0-31-42     {color: #aa0000; background-color: #00aa00;}
 .a-0-32-42     {color: #00aa00; background-color: #00aa00;}
 .a-0-33-42     {color: #aaaa00; background-color: #00aa00;}
@@ -378,8 +400,8 @@ a:link         {text-decoration: none;}
 .a-1-34-42     {color: #4444ff; background-color: #00aa00;}
 .a-1-35-42     {color: #ff44ff; background-color: #00aa00;}
 .a-1-36-42     {color: #44ffff; background-color: #00aa00;}
-.a-1-37-42     {color: white; background-color: #00aa00;}
-.a-0-30-43     {color: black; background-color: #aaaa00;}
+.a-1-37-42     {color: #ffffff; background-color: #00aa00;}
+.a-0-30-43     {color: #000000; background-color: #aaaa00;}
 .a-0-31-43     {color: #aa0000; background-color: #aaaa00;}
 .a-0-32-43     {color: #00aa00; background-color: #aaaa00;}
 .a-0-33-43     {color: #aaaa00; background-color: #aaaa00;}
@@ -394,8 +416,8 @@ a:link         {text-decoration: none;}
 .a-1-34-43     {color: #4444ff; background-color: #aaaa00;}
 .a-1-35-43     {color: #ff44ff; background-color: #aaaa00;}
 .a-1-36-43     {color: #44ffff; background-color: #aaaa00;}
-.a-1-37-43     {color: white; background-color: #aaaa00;}
-.a-0-30-44     {color: black; background-color: #0000aa;}
+.a-1-37-43     {color: #ffffff; background-color: #aaaa00;}
+.a-0-30-44     {color: #000000; background-color: #0000aa;}
 .a-0-31-44     {color: #aa0000; background-color: #0000aa;}
 .a-0-32-44     {color: #00aa00; background-color: #0000aa;}
 .a-0-33-44     {color: #aaaa00; background-color: #0000aa;}
@@ -410,8 +432,8 @@ a:link         {text-decoration: none;}
 .a-1-34-44     {color: #4444ff; background-color: #0000aa;}
 .a-1-35-44     {color: #ff44ff; background-color: #0000aa;}
 .a-1-36-44     {color: #44ffff; background-color: #0000aa;}
-.a-1-37-44     {color: white; background-color: #0000aa;}
-.a-0-30-45     {color: black; background-color: #aa00aa;}
+.a-1-37-44     {color: #ffffff; background-color: #0000aa;}
+.a-0-30-45     {color: #000000; background-color: #aa00aa;}
 .a-0-31-45     {color: #aa0000; background-color: #aa00aa;}
 .a-0-32-45     {color: #00aa00; background-color: #aa00aa;}
 .a-0-33-45     {color: #aaaa00; background-color: #aa00aa;}
@@ -426,8 +448,8 @@ a:link         {text-decoration: none;}
 .a-1-34-45     {color: #4444ff; background-color: #aa00aa;}
 .a-1-35-45     {color: #ff44ff; background-color: #aa00aa;}
 .a-1-36-45     {color: #44ffff; background-color: #aa00aa;}
-.a-1-37-45     {color: white; background-color: #aa00aa;}
-.a-0-30-46     {color: black; background-color: #44ffff;}
+.a-1-37-45     {color: #ffffff; background-color: #aa00aa;}
+.a-0-30-46     {color: #000000; background-color: #44ffff;}
 .a-0-31-46     {color: #aa0000; background-color: #44ffff;}
 .a-0-32-46     {color: #00aa00; background-color: #44ffff;}
 .a-0-33-46     {color: #aaaa00; background-color: #44ffff;}
@@ -442,8 +464,8 @@ a:link         {text-decoration: none;}
 .a-1-34-46     {color: #4444ff; background-color: #44ffff;}
 .a-1-35-46     {color: #ff44ff; background-color: #44ffff;}
 .a-1-36-46     {color: #44ffff; background-color: #44ffff;}
-.a-1-37-46     {color: white; background-color: #44ffff;}
-.a-0-30-47     {color: black; background-color: #aaaaaa;}
+.a-1-37-46     {color: #ffffff; background-color: #44ffff;}
+.a-0-30-47     {color: #000000; background-color: #aaaaaa;}
 .a-0-31-47     {color: #aa0000; background-color: #aaaaaa;}
 .a-0-32-47     {color: #00aa00; background-color: #aaaaaa;}
 .a-0-33-47     {color: #aaaa00; background-color: #aaaaaa;}
@@ -458,24 +480,24 @@ a:link         {text-decoration: none;}
 .a-1-34-47     {color: #4444ff; background-color: #aaaaaa;}
 .a-1-35-47     {color: #ff44ff; background-color: #aaaaaa;}
 .a-1-36-47     {color: #44ffff; background-color: #aaaaaa;}
-.a-1-37-47     {color: white; background-color: #aaaaaa;}
-.a5-0-30-40    {text-decoration: blink; color: black; background-color: black;}
-.a5-0-31-40    {text-decoration: blink; color: #aa0000; background-color: black;}
-.a5-0-32-40    {text-decoration: blink; color: #00aa00; background-color: black;}
-.a5-0-33-40    {text-decoration: blink; color: #aaaa00; background-color: black;}
-.a5-0-34-40    {text-decoration: blink; color: #0000aa; background-color: black;}
-.a5-0-35-40    {text-decoration: blink; color: #aa00aa; background-color: black;}
-.a5-0-36-40    {text-decoration: blink; color: #00aaaa; background-color: black;}
-.a5-0-37-40    {text-decoration: blink; color: #aaaaaa; background-color: black;}
-.a5-1-30-40    {text-decoration: blink; color: #444444; background-color: black;}
-.a5-1-31-40    {text-decoration: blink; color: #ff4444; background-color: black;}
-.a5-1-32-40    {text-decoration: blink; color: #44ff44; background-color: black;}
-.a5-1-33-40    {text-decoration: blink; color: #ffff44; background-color: black;}
-.a5-1-34-40    {text-decoration: blink; color: #4444ff; background-color: black;}
-.a5-1-35-40    {text-decoration: blink; color: #ff44ff; background-color: black;}
-.a5-1-36-40    {text-decoration: blink; color: #44ffff; background-color: black;}
-.a5-1-37-40    {text-decoration: blink; color: white; background-color: black;}
-.a5-0-30-41    {text-decoration: blink; color: black; background-color: #aa0000;}
+.a-1-37-47     {color: #ffffff; background-color: #aaaaaa;}
+.a5-0-30-40    {text-decoration: blink; color: #000000; background-color: #000000;}
+.a5-0-31-40    {text-decoration: blink; color: #aa0000; background-color: #000000;}
+.a5-0-32-40    {text-decoration: blink; color: #00aa00; background-color: #000000;}
+.a5-0-33-40    {text-decoration: blink; color: #aaaa00; background-color: #000000;}
+.a5-0-34-40    {text-decoration: blink; color: #0000aa; background-color: #000000;}
+.a5-0-35-40    {text-decoration: blink; color: #aa00aa; background-color: #000000;}
+.a5-0-36-40    {text-decoration: blink; color: #00aaaa; background-color: #000000;}
+.a5-0-37-40    {text-decoration: blink; color: #aaaaaa; background-color: #000000;}
+.a5-1-30-40    {text-decoration: blink; color: #444444; background-color: #000000;}
+.a5-1-31-40    {text-decoration: blink; color: #ff4444; background-color: #000000;}
+.a5-1-32-40    {text-decoration: blink; color: #44ff44; background-color: #000000;}
+.a5-1-33-40    {text-decoration: blink; color: #ffff44; background-color: #000000;}
+.a5-1-34-40    {text-decoration: blink; color: #4444ff; background-color: #000000;}
+.a5-1-35-40    {text-decoration: blink; color: #ff44ff; background-color: #000000;}
+.a5-1-36-40    {text-decoration: blink; color: #44ffff; background-color: #000000;}
+.a5-1-37-40    {text-decoration: blink; color: #ffffff; background-color: #000000;}
+.a5-0-30-41    {text-decoration: blink; color: #000000; background-color: #aa0000;}
 .a5-0-31-41    {text-decoration: blink; color: #aa0000; background-color: #aa0000;}
 .a5-0-32-41    {text-decoration: blink; color: #00aa00; background-color: #aa0000;}
 .a5-0-33-41    {text-decoration: blink; color: #aaaa00; background-color: #aa0000;}
@@ -490,8 +512,8 @@ a:link         {text-decoration: none;}
 .a5-1-34-41    {text-decoration: blink; color: #4444ff; background-color: #aa0000;}
 .a5-1-35-41    {text-decoration: blink; color: #ff44ff; background-color: #aa0000;}
 .a5-1-36-41    {text-decoration: blink; color: #44ffff; background-color: #aa0000;}
-.a5-1-37-41    {text-decoration: blink; color: white; background-color: #aa0000;}
-.a5-0-30-42    {text-decoration: blink; color: black; background-color: #00aa00;}
+.a5-1-37-41    {text-decoration: blink; color: #ffffff; background-color: #aa0000;}
+.a5-0-30-42    {text-decoration: blink; color: #000000; background-color: #00aa00;}
 .a5-0-31-42    {text-decoration: blink; color: #aa0000; background-color: #00aa00;}
 .a5-0-32-42    {text-decoration: blink; color: #00aa00; background-color: #00aa00;}
 .a5-0-33-42    {text-decoration: blink; color: #aaaa00; background-color: #00aa00;}
@@ -506,8 +528,8 @@ a:link         {text-decoration: none;}
 .a5-1-34-42    {text-decoration: blink; color: #4444ff; background-color: #00aa00;}
 .a5-1-35-42    {text-decoration: blink; color: #ff44ff; background-color: #00aa00;}
 .a5-1-36-42    {text-decoration: blink; color: #44ffff; background-color: #00aa00;}
-.a5-1-37-42    {text-decoration: blink; color: white; background-color: #00aa00;}
-.a5-0-30-43    {text-decoration: blink; color: black; background-color: #aaaa00;}
+.a5-1-37-42    {text-decoration: blink; color: #ffffff; background-color: #00aa00;}
+.a5-0-30-43    {text-decoration: blink; color: #000000; background-color: #aaaa00;}
 .a5-0-31-43    {text-decoration: blink; color: #aa0000; background-color: #aaaa00;}
 .a5-0-32-43    {text-decoration: blink; color: #00aa00; background-color: #aaaa00;}
 .a5-0-33-43    {text-decoration: blink; color: #aaaa00; background-color: #aaaa00;}
@@ -522,8 +544,8 @@ a:link         {text-decoration: none;}
 .a5-1-34-43    {text-decoration: blink; color: #4444ff; background-color: #aaaa00;}
 .a5-1-35-43    {text-decoration: blink; color: #ff44ff; background-color: #aaaa00;}
 .a5-1-36-43    {text-decoration: blink; color: #44ffff; background-color: #aaaa00;}
-.a5-1-37-43    {text-decoration: blink; color: white; background-color: #aaaa00;}
-.a5-0-30-44    {text-decoration: blink; color: black; background-color: #0000aa;}
+.a5-1-37-43    {text-decoration: blink; color: #ffffff; background-color: #aaaa00;}
+.a5-0-30-44    {text-decoration: blink; color: #000000; background-color: #0000aa;}
 .a5-0-31-44    {text-decoration: blink; color: #aa0000; background-color: #0000aa;}
 .a5-0-32-44    {text-decoration: blink; color: #00aa00; background-color: #0000aa;}
 .a5-0-33-44    {text-decoration: blink; color: #aaaa00; background-color: #0000aa;}
@@ -538,8 +560,8 @@ a:link         {text-decoration: none;}
 .a5-1-34-44    {text-decoration: blink; color: #4444ff; background-color: #0000aa;}
 .a5-1-35-44    {text-decoration: blink; color: #ff44ff; background-color: #0000aa;}
 .a5-1-36-44    {text-decoration: blink; color: #44ffff; background-color: #0000aa;}
-.a5-1-37-44    {text-decoration: blink; color: white; background-color: #0000aa;}
-.a5-0-30-45    {text-decoration: blink; color: black; background-color: #aa00aa;}
+.a5-1-37-44    {text-decoration: blink; color: #ffffff; background-color: #0000aa;}
+.a5-0-30-45    {text-decoration: blink; color: #000000; background-color: #aa00aa;}
 .a5-0-31-45    {text-decoration: blink; color: #aa0000; background-color: #aa00aa;}
 .a5-0-32-45    {text-decoration: blink; color: #00aa00; background-color: #aa00aa;}
 .a5-0-33-45    {text-decoration: blink; color: #aaaa00; background-color: #aa00aa;}
@@ -554,8 +576,8 @@ a:link         {text-decoration: none;}
 .a5-1-34-45    {text-decoration: blink; color: #4444ff; background-color: #aa00aa;}
 .a5-1-35-45    {text-decoration: blink; color: #ff44ff; background-color: #aa00aa;}
 .a5-1-36-45    {text-decoration: blink; color: #44ffff; background-color: #aa00aa;}
-.a5-1-37-45    {text-decoration: blink; color: white; background-color: #aa00aa;}
-.a5-0-30-46    {text-decoration: blink; color: black; background-color: #44ffff;}
+.a5-1-37-45    {text-decoration: blink; color: #ffffff; background-color: #aa00aa;}
+.a5-0-30-46    {text-decoration: blink; color: #000000; background-color: #44ffff;}
 .a5-0-31-46    {text-decoration: blink; color: #aa0000; background-color: #44ffff;}
 .a5-0-32-46    {text-decoration: blink; color: #00aa00; background-color: #44ffff;}
 .a5-0-33-46    {text-decoration: blink; color: #aaaa00; background-color: #44ffff;}
@@ -570,8 +592,8 @@ a:link         {text-decoration: none;}
 .a5-1-34-46    {text-decoration: blink; color: #4444ff; background-color: #44ffff;}
 .a5-1-35-46    {text-decoration: blink; color: #ff44ff; background-color: #44ffff;}
 .a5-1-36-46    {text-decoration: blink; color: #44ffff; background-color: #44ffff;}
-.a5-1-37-46    {text-decoration: blink; color: white; background-color: #44ffff;}
-.a5-0-30-47    {text-decoration: blink; color: black; background-color: #aaaaaa;}
+.a5-1-37-46    {text-decoration: blink; color: #ffffff; background-color: #44ffff;}
+.a5-0-30-47    {text-decoration: blink; color: #000000; background-color: #aaaaaa;}
 .a5-0-31-47    {text-decoration: blink; color: #aa0000; background-color: #aaaaaa;}
 .a5-0-32-47    {text-decoration: blink; color: #00aa00; background-color: #aaaaaa;}
 .a5-0-33-47    {text-decoration: blink; color: #aaaa00; background-color: #aaaaaa;}
@@ -586,4 +608,4 @@ a:link         {text-decoration: none;}
 .a5-1-34-47    {text-decoration: blink; color: #4444ff; background-color: #aaaaaa;}
 .a5-1-35-47    {text-decoration: blink; color: #ff44ff; background-color: #aaaaaa;}
 .a5-1-36-47    {text-decoration: blink; color: #44ffff; background-color: #aaaaaa;}
-.a5-1-37-47    {text-decoration: blink; color: white; background-color: #aaaaaa;}
+.a5-1-37-47    {text-decoration: blink; color: #ffffff; background-color: #aaaaaa;}
